self.__BUILD_MANIFEST=function(s,c,a,t,e,f,u,n,b,o,j,r,i,k,d){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-444f1804401f04ea.js"],"/_error":["static/chunks/pages/_error-c66a4e8afc46f17b.js"],"/clusters":["static/chunks/pages/clusters-2f61f65487f6d8ff.js"],"/clusters/[cluster]":[s,c,a,f,u,j,o,t,e,n,r,b,i,k,d,"static/chunks/6856-5fdc9b851a18acdb.js","static/chunks/1871-49141c317f3a9020.js","static/chunks/pages/clusters/[cluster]-477555ab7c0b13d8.js"],"/clusters/[cluster]/[job]":[s,c,a,f,t,e,b,"static/chunks/pages/clusters/[cluster]/[job]-8f058b0346db2aff.js"],"/config":["static/chunks/pages/config-dfb9bf07b13045f4.js"],"/infra":["static/chunks/pages/infra-910a22500c50596f.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-553b8b5cb65e100b.js"],"/jobs":["static/chunks/pages/jobs-a35a9dc3c5ccd657.js"],"/jobs/pools/[pool]":[s,c,a,u,o,t,e,n,"static/chunks/pages/jobs/pools/[pool]-bc979970c247d8f3.js"],"/jobs/[job]":[s,c,a,f,u,o,t,e,n,b,"static/chunks/pages/jobs/[job]-4f7079dcab6ed653.js"],"/users":["static/chunks/pages/users-98d2ed979084162a.js"],"/volumes":["static/chunks/pages/volumes-835d14ba94808f79.js"],"/workspace/new":["static/chunks/pages/workspace/new-3f88a1c7e86a3f86.js"],"/workspaces":["static/chunks/pages/workspaces-69c80d677d3c2949.js"],"/workspaces/[name]":[s,c,a,f,u,j,t,e,n,r,b,i,k,d,"static/chunks/1141-3b40c39626f99c89.js","static/chunks/pages/workspaces/[name]-e8688c35c06f0ac5.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/616-3d59f75e2ccf9321.js","static/chunks/6130-2be46d70a38f1e82.js","static/chunks/5739-d67458fcb1386c92.js","static/chunks/6989-01359c57e018caa4.js","static/chunks/3850-ff4a9a69d978632b.js","static/chunks/7411-b15471acd2cba716.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/8969-66237729cdf9749e.js","static/chunks/6135-4b4d5e824b7f9d3c.js","static/chunks/6212-7bd06f60ba693125.js","static/chunks/7359-c8d04e06886000b3.js","static/chunks/6990-f6818c84ed8f1c86.js","static/chunks/1121-d0782b9251f0fcd3.js","static/chunks/6601-06114c982db410b6.js","static/chunks/3015-8d748834fcc60b46.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();